# Common C/C++ Toolchain (GCC/Clang)

__Options__:

- `.toolkit`
- `.crossfile`
- `.debug`
- `.rtti`
- `.as`
- `.c`
- `.cpp`
- `.ar`
- `.cpp_stdlib`
- `.exflags` &ndash; Take external flags like `CFLAGS`, `CPPFLAGS`, `ASMFLAGS`,
  `LDFLAGS` and `LDLIBS` into account
